## 3.1.0b1
**Fixed**
* Fixed six package error. Upgrade all the necessary packages
* Fixed django query error with None value

## 0.1.5
**Fixed**
* Fixed six package error. Downgrade django version

## 0.1.4
**Added**
* Django and Python updated version on setup.py
**Updated**
* Removed predefined `/api/` before graphql API. So, user can decide their own endpoint name
* Updated README.md file for url initiating

## 0.1.3
**Fixed**
* django auth app user is not responding in graphql api

## 0.1.2
**Added**
* Added minimal Token based authentication
* Added Some exception handler class for exception handling
* Added model and migrations for AuthToken model
